---
id: llamaindex
name: LlamaIndex
---

# LlamaIndex

- `LlamaIndex` [Vector Store page](https://docs.llamaindex.ai/en/stable/examples/vector_stores/ChromaIndexDemo.html)
- [Demo](https://github.com/jerryjliu/llama_index/blob/main/docs/examples/vector_stores/ChromaIndexDemo.ipynb)
- [Chroma Loader on Llamahub](https://llamahub.ai/l/chroma)
